==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/pintuan/PinItem.java <==
package eleme.openapi.sdk.api.entity.pintuan;

import eleme.openapi.sdk.api.entity.pintuan.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class PinItem{

    /**
     * 商品ID
     */
    private Long pinItemId;
    public Long getPinItemId() {
        return pinItemId;
    }
    public void setPinItemId(Long pinItemId) {
        this.pinItemId = pinItemId;
    }
    
    /**
     * 商品extCode
     */
    private String extCode;
    public String getExtCode() {
        return extCode;
    }
    public void setExtCode(String extCode) {
        this.extCode = extCode;
    }
    
    /**
     * 商品名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 上下架状态
     */
    private Integer onShelf;
    public Integer getOnShelf() {
        return onShelf;
    }
    public void setOnShelf(Integer onShelf) {
        this.onShelf = onShelf;
    }
    
    /**
     * 规格信息
     */
    private List<PinSku> skus;
    public List<PinSku> getSkus() {
        return skus;
    }
    public void setSkus(List<PinSku> skus) {
        this.skus = skus;
    }
    
    /**
     * 商品描述
     */
    private String description;
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    
    /**
     * 库存
     */
    private Integer stock;
    public Integer getStock() {
        return stock;
    }
    public void setStock(Integer stock) {
        this.stock = stock;
    }
    
}

==> eleme-openapi-sdk-1.30.85-sources.jar: eleme/openapi/sdk/api/entity/pintuan/PinItem.java <==
package eleme.openapi.sdk.api.entity.pintuan;

import eleme.openapi.sdk.api.enumeration.pintuan.*;
import eleme.openapi.sdk.api.entity.pintuan.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class PinItem{

    /**
     * 商品ID
     */
    private Long pinItemId;
    public Long getPinItemId() {
        return pinItemId;
    }
    public void setPinItemId(Long pinItemId) {
        this.pinItemId = pinItemId;
    }
    
    /**
     * 商品extCode
     */
    private String extCode;
    public String getExtCode() {
        return extCode;
    }
    public void setExtCode(String extCode) {
        this.extCode = extCode;
    }
    
    /**
     * 商品名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 上下架状态
     */
    private Integer onShelf;
    public Integer getOnShelf() {
        return onShelf;
    }
    public void setOnShelf(Integer onShelf) {
        this.onShelf = onShelf;
    }
    
    /**
     * 规格信息
     */
    private List<PinSku> skus;
    public List<PinSku> getSkus() {
        return skus;
    }
    public void setSkus(List<PinSku> skus) {
        this.skus = skus;
    }
    
    /**
     * 商品描述
     */
    private String description;
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    
    /**
     * 库存
     */
    private Integer stock;
    public Integer getStock() {
        return stock;
    }
    public void setStock(Integer stock) {
        this.stock = stock;
    }
    
    /**
     * 最大库存
     */
    private Integer maxStock;
    public Integer getMaxStock() {
        return maxStock;
    }
    public void setMaxStock(Integer maxStock) {
        this.maxStock = maxStock;
    }
    
    /**
     * 库存状态
     */
    private Integer stockStatus;
    public Integer getStockStatus() {
        return stockStatus;
    }
    public void setStockStatus(Integer stockStatus) {
        this.stockStatus = stockStatus;
    }
    
    /**
     * 拼团商品属性
     */
    private List<PinItemAttribute> attributes;
    public List<PinItemAttribute> getAttributes() {
        return attributes;
    }
    public void setAttributes(List<PinItemAttribute> attributes) {
        this.attributes = attributes;
    }
    
    /**
     * 商品图片
     */
    private String imageUrl;
    public String getImageUrl() {
        return imageUrl;
    }
    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }
    
}
